<?php

/**
 * @file
 * Contains \Drupal\drd\Crypt\BaseMethod.
 */

namespace Drupal\drd\Crypt;

/**
 * Provides base encryption method.
 *
 * @ingroup drd
 */
abstract class BaseMethod implements BaseMethodInterface {

  /**
   * @inheritDoc
   */
  public function requiresPassword() {
    return TRUE;
  }

  /**
   * @inheritDoc
   */
  public function resetPassword() {
    return $this;
  }

  /**
   * @inheritDoc
   */
  public function getSettings() {
    return array();
  }

  /**
   * Returns base64 encoded random bytes of the given length.
   *
   * @param $length
   * @return string
   */
  protected function generatePassword($length) {
    try {
      $randomBytes = random_bytes($length);
    }
    catch (\Exception $e) {
      drupal_set_message(t('Your system does not provide real good random data, hence you should fix that first before you continue with DRD!'), 'error');
      return '';
    }
    return base64_encode($randomBytes);
  }

}
