<?php

namespace Drupal\drd\Plugin\Update;

use Drupal\Core\Annotation\Translation;
use Drupal\Core\Form\FormStateInterface;
use GitElephant\Repository;

/**
 * Provides a composer based update plugin with sources in a Git repository.
 *
 * @Update(
 *  id = "composer_git",
 *  admin_label = @Translation("Composer Git"),
 * )
 */
class ComposerGit extends Composer {

  /** @var Repository */
  protected $repository;

  /**
   * @inheritDoc
   */
  public function defaultConfiguration() {
    return [
      'repository' => '',
      'branch' => '',
    ] + parent::defaultConfiguration();
  }

  /**
   * @inheritDoc
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $element = parent::buildConfigurationForm($form, $form_state);

    $element['repository'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Git repository'),
      '#default_value' => $this->configuration['repository'],
      '#states' => array(
        'required' => $this->condition,
      ),
    ];
    $element['branch'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Branch'),
      '#default_value' => $this->configuration['branch'],
      '#states' => array(
        'required' => $this->condition,
      ),
    ];

    return $element;
  }

  /**
   * @inheritDoc
   */
  public function validateConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::validateConfigurationForm($form, $form_state);
  }

  /**
   * @inheritDoc
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::submitConfigurationForm($form, $form_state);
    $this->configuration['repository'] = $form_state->getValue([$this->pluginId, 'repository']);
    $this->configuration['branch'] = $form_state->getValue([$this->pluginId, 'branch']);
  }

  /**
   * @inheritDoc
   */
  public function prepareWorkingDirectory() {
    parent::prepareWorkingDirectory();

    // Git Clone the repository into the working directory
    $this->repository = Repository::open($this->workingDirectory);
    $this->repository->cloneFrom($this->configuration['repository'], '.');
    $this->repository->checkout($this->configuration['branch']);

    return $this;
  }

  /**
   * @inheritDoc
   */
  public function updateWorkingDirectory($releases) {
    parent::updateWorkingDirectory($releases);

    // Commit changes and push upstream
    if ($this->repository->getStatus()->all()->count()) {
      $this->repository->commit('DRD Update', TRUE);
      $this->repository->push();
    }

    return $this;
  }

}
