<?php

namespace Drupal\drd\Plugin\Update;

use Drupal\Core\Annotation\Translation;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a composer based update plugin with sources in a Git repository and
 * a GitFlow based workflow.
 *
 * @Update(
 *  id = "composer_gitflow",
 *  admin_label = @Translation("Composer GitFlow"),
 * )
 */
class ComposerGitFlow extends ComposerGit {

  /**
   * @inheritDoc
   */
  public function defaultConfiguration() {
    return [
      'branch' => 'develop',
      'pattern' => 'Y-m-d-H-s',
    ] + parent::defaultConfiguration();
  }

  /**
   * @inheritDoc
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $element = parent::buildConfigurationForm($form, $form_state);

    $element['pattern'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Pattern for release branch name'),
      '#default_value' => $this->configuration['pattern'],
      '#states' => array(
        'required' => $this->condition,
      ),
    ];

    return $element;
  }

  /**
   * @inheritDoc
   */
  public function validateConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::validateConfigurationForm($form, $form_state);
    # TODO: Validate that git flow is installed
  }

  /**
   * @inheritDoc
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::submitConfigurationForm($form, $form_state);
    $this->configuration['pattern'] = $form_state->getValue([$this->pluginId, 'pattern']);
  }

  /**
   * @inheritDoc
   */
  public function updateWorkingDirectory($releases) {
    parent::updateWorkingDirectory($releases);

    // Get the release name
    $name = \Drupal::service('date.formatter')->format(\Drupal::time()->getRequestTime(), 'custom', $this->configuration['pattern']);

    // Call GitFlow after the update has been completed in the working directory.
    $this->repository->getCaller()->execute('flow init -d');
    $this->repository->getCaller()->execute('flow release start ' . $name);
    $this->repository->getCaller()->execute('flow release finish --push --message "Release for DRD Update"');

    return $this;
  }

}
