<?php

namespace Drupal\drd\Plugin\Update;

use Drupal\Core\Annotation\Translation;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a composer based update plugin with a locally available working
 * directory.
 *
 * @Update(
 *  id = "composer_local",
 *  admin_label = @Translation("Composer local"),
 * )
 */
class ComposerLocal extends Composer {

  /**
   * @inheritDoc
   */
  public function defaultConfiguration() {
    return [
      'workingdir' => '',
    ] + parent::defaultConfiguration();
  }

  /**
   * @inheritDoc
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $element = parent::buildConfigurationForm($form, $form_state);

    $element['workingdir'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Local working directory'),
      '#default_value' => $this->configuration['workingdir'],
      '#states' => array(
        'required' => $this->condition,
      ),
    ];

    return $element;
  }

  /**
   * @inheritDoc
   */
  public function validateConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::validateConfigurationForm($form, $form_state);

    $value = $form_state->getValue([$this->pluginId, 'workingdir']) . DIRECTORY_SEPARATOR . 'composer.json';
    if (!file_exists($value)) {
      $form_state->setError($form[$this->configFormParent][$this->pluginId]['workingdir'], $this->t('Directory doesn\'t exist or doesn\'t contain a composer.json file.'));
    }
  }

  /**
   * @inheritDoc
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::submitConfigurationForm($form, $form_state);
    $this->configuration['workingdir'] = $form_state->getValue([$this->pluginId, 'workingdir']);
  }

  /**
   * @inheritDoc
   */
  public function setWorkingDirectory() {
    $this->workingDirectory = $this->configuration['workingdir'];
    return $this;
  }

  /**
   * @inheritDoc
   */
  public function prepareWorkingDirectory() {
    // Nothing to do as we have a locally available working directory.
    return $this;
  }

  /**
   * @inheritDoc
   */
  public function cleanup() {
    // Nothing to cleanup as we want to keep the local working directory as is.
    return $this;
  }

}
