<?php

namespace Drupal\drd;

use Drupal\Component\Plugin\ConfigurablePluginInterface;
use Drupal\Core\Plugin\PluginFormInterface;
use Drupal\drd\Entity\ReleaseInterface;

/**
 * Defines the required interface for base DRD Update plugin.
 */
interface UpdatePluginBaseInterface extends ConfigurablePluginInterface, PluginFormInterface {

  /**
   * @param string $parent
   * @param string $condition
   * @return UpdatePluginInterface
   */
  public function setConfigFormContext($parent, $condition);

  /**
   * @param ReleaseInterface[] $releases
   * @return UpdatePluginInterface
   */
  public function execute($releases);

  /**
   * Determine and prepare a temporary working directory which will be used
   * during the update process and cleaned up at the end of it. Such a temp
   * directory is useful for workflows where you checkout a working copy from
   * a repository. However, if you already have a local working copy in the
   * file system accessible to the DRD web server user, then overwrite this
   * method in your plugin and return that directory yourself.
   *
   * @return UpdatePluginInterface
   */
  public function setWorkingDirectory();

  /**
   * @return UpdatePluginInterface
   */
  public function prepareWorkingDirectory();

  /**
   * @return UpdatePluginInterface
   */
  public function cleanup();

}
